Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type AppExpansion
- type AppHistoriesGetter
- type AppHistoryExpansion
- type AppHistoryInterface
- type AppInterface
- type AppResourceExpansion
- type AppResourceInterface
- type AppResourcesGetter
- type ApplicationV1Client
- func (c *ApplicationV1Client) AppHistories(namespace string) AppHistoryInterface
- func (c *ApplicationV1Client) AppResources(namespace string) AppResourceInterface
- func (c *ApplicationV1Client) Apps(namespace string) AppInterface
- func (c *ApplicationV1Client) ConfigMaps() ConfigMapInterface
- func (c *ApplicationV1Client) RESTClient() rest.Interface
- type ApplicationV1Interface
- type AppsGetter
- type ConfigMapExpansion
- type ConfigMapInterface
- type ConfigMapsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppExpansion ¶
type AppExpansion interface{}
type AppHistoriesGetter ¶
type AppHistoriesGetter interface {
AppHistories(namespace string) AppHistoryInterface
}
AppHistoriesGetter has a method to return a AppHistoryInterface. A group's client should implement this interface.
type AppHistoryExpansion ¶
type AppHistoryExpansion interface{}
type AppHistoryInterface ¶
type AppHistoryInterface interface {
AppHistoryExpansion
}
AppHistoryInterface has methods to work with AppHistory resources.
type AppInterface ¶
type AppInterface interface {
Create(ctx context.Context, app *v1.App, opts metav1.CreateOptions) (*v1.App, error)
Update(ctx context.Context, app *v1.App, opts metav1.UpdateOptions) (*v1.App, error)
UpdateStatus(ctx context.Context, app *v1.App, opts metav1.UpdateOptions) (*v1.App, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.App, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.AppList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.App, err error)
AppExpansion
}
AppInterface has methods to work with App resources.
type AppResourceExpansion ¶
type AppResourceExpansion interface{}
type AppResourceInterface ¶
type AppResourceInterface interface {
AppResourceExpansion
}
AppResourceInterface has methods to work with AppResource resources.
type AppResourcesGetter ¶
type AppResourcesGetter interface {
AppResources(namespace string) AppResourceInterface
}
AppResourcesGetter has a method to return a AppResourceInterface. A group's client should implement this interface.
type ApplicationV1Client ¶
type ApplicationV1Client struct {
// contains filtered or unexported fields
}
ApplicationV1Client is used to interact with features provided by the application.tkestack.io group.
func New ¶
func New(c rest.Interface) *ApplicationV1Client
New creates a new ApplicationV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ApplicationV1Client, error)
NewForConfig creates a new ApplicationV1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ApplicationV1Client
NewForConfigOrDie creates a new ApplicationV1Client for the given config and panics if there is an error in the config.
func (*ApplicationV1Client) AppHistories ¶
func (c *ApplicationV1Client) AppHistories(namespace string) AppHistoryInterface
func (*ApplicationV1Client) AppResources ¶
func (c *ApplicationV1Client) AppResources(namespace string) AppResourceInterface
func (*ApplicationV1Client) Apps ¶
func (c *ApplicationV1Client) Apps(namespace string) AppInterface
func (*ApplicationV1Client) ConfigMaps ¶
func (c *ApplicationV1Client) ConfigMaps() ConfigMapInterface
func (*ApplicationV1Client) RESTClient ¶
func (c *ApplicationV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type ApplicationV1Interface ¶
type ApplicationV1Interface interface {
RESTClient() rest.Interface
AppsGetter
AppHistoriesGetter
AppResourcesGetter
ConfigMapsGetter
}
type AppsGetter ¶
type AppsGetter interface {
Apps(namespace string) AppInterface
}
AppsGetter has a method to return a AppInterface. A group's client should implement this interface.
type ConfigMapExpansion ¶
type ConfigMapExpansion interface{}
type ConfigMapInterface ¶
type ConfigMapInterface interface {
Create(ctx context.Context, configMap *v1.ConfigMap, opts metav1.CreateOptions) (*v1.ConfigMap, error)
Update(ctx context.Context, configMap *v1.ConfigMap, opts metav1.UpdateOptions) (*v1.ConfigMap, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ConfigMap, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ConfigMapList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ConfigMap, err error)
ConfigMapExpansion
}
ConfigMapInterface has methods to work with ConfigMap resources.
type ConfigMapsGetter ¶
type ConfigMapsGetter interface {
ConfigMaps() ConfigMapInterface
}
ConfigMapsGetter has a method to return a ConfigMapInterface. A group's client should implement this interface.