Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type CSIOperatorExpansion
- type CSIOperatorInterface
- type CSIOperatorsGetter
- type ClusterAddonExpansion
- type ClusterAddonInterface
- type ClusterAddonTypeExpansion
- type ClusterAddonTypeInterface
- type ClusterAddonTypesGetter
- type ClusterAddonsGetter
- type ClusterCredentialExpansion
- type ClusterCredentialInterface
- type ClusterCredentialsGetter
- type ClusterExpansion
- type ClusterGroupAPIResourceItemsExpansion
- type ClusterGroupAPIResourceItemsInterface
- type ClusterGroupAPIResourceItemsesGetter
- type ClusterInterface
- type ClustersGetter
- type ConfigMapExpansion
- type ConfigMapInterface
- type ConfigMapsGetter
- type CronHPAExpansion
- type CronHPAInterface
- type CronHPAsGetter
- type MachineExpansion
- type MachineInterface
- type MachinesGetter
- type PersistentEventExpansion
- type PersistentEventInterface
- type PersistentEventsGetter
- type PlatformV1Client
- func (c *PlatformV1Client) CSIOperators() CSIOperatorInterface
- func (c *PlatformV1Client) ClusterAddonTypes() ClusterAddonTypeInterface
- func (c *PlatformV1Client) ClusterAddons() ClusterAddonInterface
- func (c *PlatformV1Client) ClusterCredentials() ClusterCredentialInterface
- func (c *PlatformV1Client) ClusterGroupAPIResourceItemses() ClusterGroupAPIResourceItemsInterface
- func (c *PlatformV1Client) Clusters() ClusterInterface
- func (c *PlatformV1Client) ConfigMaps() ConfigMapInterface
- func (c *PlatformV1Client) CronHPAs() CronHPAInterface
- func (c *PlatformV1Client) Machines() MachineInterface
- func (c *PlatformV1Client) PersistentEvents() PersistentEventInterface
- func (c *PlatformV1Client) RESTClient() rest.Interface
- func (c *PlatformV1Client) Registries() RegistryInterface
- func (c *PlatformV1Client) TappControllers() TappControllerInterface
- type PlatformV1Interface
- type RegistriesGetter
- type RegistryExpansion
- type RegistryInterface
- type TappControllerExpansion
- type TappControllerInterface
- type TappControllersGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CSIOperatorExpansion ¶
type CSIOperatorExpansion interface{}
type CSIOperatorInterface ¶
type CSIOperatorInterface interface {
Create(ctx context.Context, cSIOperator *v1.CSIOperator, opts metav1.CreateOptions) (*v1.CSIOperator, error)
Update(ctx context.Context, cSIOperator *v1.CSIOperator, opts metav1.UpdateOptions) (*v1.CSIOperator, error)
UpdateStatus(ctx context.Context, cSIOperator *v1.CSIOperator, opts metav1.UpdateOptions) (*v1.CSIOperator, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.CSIOperator, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.CSIOperatorList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.CSIOperator, err error)
CSIOperatorExpansion
}
CSIOperatorInterface has methods to work with CSIOperator resources.
type CSIOperatorsGetter ¶
type CSIOperatorsGetter interface {
CSIOperators() CSIOperatorInterface
}
CSIOperatorsGetter has a method to return a CSIOperatorInterface. A group's client should implement this interface.
type ClusterAddonExpansion ¶
type ClusterAddonExpansion interface{}
type ClusterAddonInterface ¶
type ClusterAddonInterface interface {
Get(ctx context.Context, name string, opts v1.GetOptions) (*platformv1.ClusterAddon, error)
List(ctx context.Context, opts v1.ListOptions) (*platformv1.ClusterAddonList, error)
ClusterAddonExpansion
}
ClusterAddonInterface has methods to work with ClusterAddon resources.
type ClusterAddonTypeExpansion ¶
type ClusterAddonTypeExpansion interface{}
type ClusterAddonTypeInterface ¶
type ClusterAddonTypeInterface interface {
List(ctx context.Context, opts v1.ListOptions) (*platformv1.ClusterAddonTypeList, error)
ClusterAddonTypeExpansion
}
ClusterAddonTypeInterface has methods to work with ClusterAddonType resources.
type ClusterAddonTypesGetter ¶
type ClusterAddonTypesGetter interface {
ClusterAddonTypes() ClusterAddonTypeInterface
}
ClusterAddonTypesGetter has a method to return a ClusterAddonTypeInterface. A group's client should implement this interface.
type ClusterAddonsGetter ¶
type ClusterAddonsGetter interface {
ClusterAddons() ClusterAddonInterface
}
ClusterAddonsGetter has a method to return a ClusterAddonInterface. A group's client should implement this interface.
type ClusterCredentialExpansion ¶
type ClusterCredentialExpansion interface{}
type ClusterCredentialInterface ¶
type ClusterCredentialInterface interface {
Create(ctx context.Context, clusterCredential *v1.ClusterCredential, opts metav1.CreateOptions) (*v1.ClusterCredential, error)
Update(ctx context.Context, clusterCredential *v1.ClusterCredential, opts metav1.UpdateOptions) (*v1.ClusterCredential, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ClusterCredential, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ClusterCredentialList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ClusterCredential, err error)
ClusterCredentialExpansion
}
ClusterCredentialInterface has methods to work with ClusterCredential resources.
type ClusterCredentialsGetter ¶
type ClusterCredentialsGetter interface {
ClusterCredentials() ClusterCredentialInterface
}
ClusterCredentialsGetter has a method to return a ClusterCredentialInterface. A group's client should implement this interface.
type ClusterExpansion ¶
type ClusterExpansion interface{}
type ClusterGroupAPIResourceItemsExpansion ¶ added in v1.8.0
type ClusterGroupAPIResourceItemsExpansion interface{}
type ClusterGroupAPIResourceItemsInterface ¶ added in v1.8.0
type ClusterGroupAPIResourceItemsInterface interface {
Get(ctx context.Context, name string, opts v1.GetOptions) (*platformv1.ClusterGroupAPIResourceItems, error)
List(ctx context.Context, opts v1.ListOptions) (*platformv1.ClusterGroupAPIResourceItemsList, error)
ClusterGroupAPIResourceItemsExpansion
}
ClusterGroupAPIResourceItemsInterface has methods to work with ClusterGroupAPIResourceItems resources.
type ClusterGroupAPIResourceItemsesGetter ¶ added in v1.8.0
type ClusterGroupAPIResourceItemsesGetter interface {
ClusterGroupAPIResourceItemses() ClusterGroupAPIResourceItemsInterface
}
ClusterGroupAPIResourceItemsesGetter has a method to return a ClusterGroupAPIResourceItemsInterface. A group's client should implement this interface.
type ClusterInterface ¶
type ClusterInterface interface {
Create(ctx context.Context, cluster *v1.Cluster, opts metav1.CreateOptions) (*v1.Cluster, error)
Update(ctx context.Context, cluster *v1.Cluster, opts metav1.UpdateOptions) (*v1.Cluster, error)
UpdateStatus(ctx context.Context, cluster *v1.Cluster, opts metav1.UpdateOptions) (*v1.Cluster, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.Cluster, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ClusterList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Cluster, err error)
ClusterExpansion
}
ClusterInterface has methods to work with Cluster resources.
type ClustersGetter ¶
type ClustersGetter interface {
Clusters() ClusterInterface
}
ClustersGetter has a method to return a ClusterInterface. A group's client should implement this interface.
type ConfigMapExpansion ¶
type ConfigMapExpansion interface{}
type ConfigMapInterface ¶
type ConfigMapInterface interface {
Create(ctx context.Context, configMap *v1.ConfigMap, opts metav1.CreateOptions) (*v1.ConfigMap, error)
Update(ctx context.Context, configMap *v1.ConfigMap, opts metav1.UpdateOptions) (*v1.ConfigMap, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ConfigMap, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ConfigMapList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ConfigMap, err error)
ConfigMapExpansion
}
ConfigMapInterface has methods to work with ConfigMap resources.
type ConfigMapsGetter ¶
type ConfigMapsGetter interface {
ConfigMaps() ConfigMapInterface
}
ConfigMapsGetter has a method to return a ConfigMapInterface. A group's client should implement this interface.
type CronHPAExpansion ¶
type CronHPAExpansion interface{}
type CronHPAInterface ¶
type CronHPAInterface interface {
Create(ctx context.Context, cronHPA *v1.CronHPA, opts metav1.CreateOptions) (*v1.CronHPA, error)
Update(ctx context.Context, cronHPA *v1.CronHPA, opts metav1.UpdateOptions) (*v1.CronHPA, error)
UpdateStatus(ctx context.Context, cronHPA *v1.CronHPA, opts metav1.UpdateOptions) (*v1.CronHPA, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.CronHPA, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.CronHPAList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.CronHPA, err error)
CronHPAExpansion
}
CronHPAInterface has methods to work with CronHPA resources.
type CronHPAsGetter ¶
type CronHPAsGetter interface {
CronHPAs() CronHPAInterface
}
CronHPAsGetter has a method to return a CronHPAInterface. A group's client should implement this interface.
type MachineExpansion ¶
type MachineExpansion interface{}
type MachineInterface ¶
type MachineInterface interface {
Create(ctx context.Context, machine *v1.Machine, opts metav1.CreateOptions) (*v1.Machine, error)
Update(ctx context.Context, machine *v1.Machine, opts metav1.UpdateOptions) (*v1.Machine, error)
UpdateStatus(ctx context.Context, machine *v1.Machine, opts metav1.UpdateOptions) (*v1.Machine, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.Machine, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.MachineList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Machine, err error)
MachineExpansion
}
MachineInterface has methods to work with Machine resources.
type MachinesGetter ¶
type MachinesGetter interface {
Machines() MachineInterface
}
MachinesGetter has a method to return a MachineInterface. A group's client should implement this interface.
type PersistentEventExpansion ¶
type PersistentEventExpansion interface{}
type PersistentEventInterface ¶
type PersistentEventInterface interface {
Create(ctx context.Context, persistentEvent *v1.PersistentEvent, opts metav1.CreateOptions) (*v1.PersistentEvent, error)
Update(ctx context.Context, persistentEvent *v1.PersistentEvent, opts metav1.UpdateOptions) (*v1.PersistentEvent, error)
UpdateStatus(ctx context.Context, persistentEvent *v1.PersistentEvent, opts metav1.UpdateOptions) (*v1.PersistentEvent, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.PersistentEvent, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.PersistentEventList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.PersistentEvent, err error)
PersistentEventExpansion
}
PersistentEventInterface has methods to work with PersistentEvent resources.
type PersistentEventsGetter ¶
type PersistentEventsGetter interface {
PersistentEvents() PersistentEventInterface
}
PersistentEventsGetter has a method to return a PersistentEventInterface. A group's client should implement this interface.
type PlatformV1Client ¶
type PlatformV1Client struct {
// contains filtered or unexported fields
}
PlatformV1Client is used to interact with features provided by the platform.tkestack.io group.
func New ¶
func New(c rest.Interface) *PlatformV1Client
New creates a new PlatformV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*PlatformV1Client, error)
NewForConfig creates a new PlatformV1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *PlatformV1Client
NewForConfigOrDie creates a new PlatformV1Client for the given config and panics if there is an error in the config.
func (*PlatformV1Client) CSIOperators ¶
func (c *PlatformV1Client) CSIOperators() CSIOperatorInterface
func (*PlatformV1Client) ClusterAddonTypes ¶
func (c *PlatformV1Client) ClusterAddonTypes() ClusterAddonTypeInterface
func (*PlatformV1Client) ClusterAddons ¶
func (c *PlatformV1Client) ClusterAddons() ClusterAddonInterface
func (*PlatformV1Client) ClusterCredentials ¶
func (c *PlatformV1Client) ClusterCredentials() ClusterCredentialInterface
func (*PlatformV1Client) ClusterGroupAPIResourceItemses ¶ added in v1.8.0
func (c *PlatformV1Client) ClusterGroupAPIResourceItemses() ClusterGroupAPIResourceItemsInterface
func (*PlatformV1Client) Clusters ¶
func (c *PlatformV1Client) Clusters() ClusterInterface
func (*PlatformV1Client) ConfigMaps ¶
func (c *PlatformV1Client) ConfigMaps() ConfigMapInterface
func (*PlatformV1Client) CronHPAs ¶
func (c *PlatformV1Client) CronHPAs() CronHPAInterface
func (*PlatformV1Client) Machines ¶
func (c *PlatformV1Client) Machines() MachineInterface
func (*PlatformV1Client) PersistentEvents ¶
func (c *PlatformV1Client) PersistentEvents() PersistentEventInterface
func (*PlatformV1Client) RESTClient ¶
func (c *PlatformV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*PlatformV1Client) Registries ¶
func (c *PlatformV1Client) Registries() RegistryInterface
func (*PlatformV1Client) TappControllers ¶
func (c *PlatformV1Client) TappControllers() TappControllerInterface
type PlatformV1Interface ¶
type PlatformV1Interface interface {
RESTClient() rest.Interface
CSIOperatorsGetter
ClustersGetter
ClusterAddonsGetter
ClusterAddonTypesGetter
ClusterCredentialsGetter
ClusterGroupAPIResourceItemsesGetter
ConfigMapsGetter
CronHPAsGetter
MachinesGetter
PersistentEventsGetter
RegistriesGetter
TappControllersGetter
}
type RegistriesGetter ¶
type RegistriesGetter interface {
Registries() RegistryInterface
}
RegistriesGetter has a method to return a RegistryInterface. A group's client should implement this interface.
type RegistryExpansion ¶
type RegistryExpansion interface{}
type RegistryInterface ¶
type RegistryInterface interface {
Create(ctx context.Context, registry *v1.Registry, opts metav1.CreateOptions) (*v1.Registry, error)
Update(ctx context.Context, registry *v1.Registry, opts metav1.UpdateOptions) (*v1.Registry, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.Registry, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.RegistryList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Registry, err error)
RegistryExpansion
}
RegistryInterface has methods to work with Registry resources.
type TappControllerExpansion ¶
type TappControllerExpansion interface{}
type TappControllerInterface ¶
type TappControllerInterface interface {
Create(ctx context.Context, tappController *v1.TappController, opts metav1.CreateOptions) (*v1.TappController, error)
Update(ctx context.Context, tappController *v1.TappController, opts metav1.UpdateOptions) (*v1.TappController, error)
UpdateStatus(ctx context.Context, tappController *v1.TappController, opts metav1.UpdateOptions) (*v1.TappController, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.TappController, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.TappControllerList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.TappController, err error)
TappControllerExpansion
}
TappControllerInterface has methods to work with TappController resources.
type TappControllersGetter ¶
type TappControllersGetter interface {
TappControllers() TappControllerInterface
}
TappControllersGetter has a method to return a TappControllerInterface. A group's client should implement this interface.